@@ -19,6 +19,7 @@
 OpenStack Client interface. Handles the REST calls and responses.
 """
 
+import json
 import logging
 
 from keystoneauth1 import adapter
@@ -35,16 +36,6 @@ try:
 except ImportError:
     import time as sleep_lib
 
-try:
-    import json
-except ImportError:
-    import simplejson as json
-
-# Python 2.5 compat fix
-if not hasattr(urlparse, 'parse_qsl'):
-    import cgi
-    urlparse.parse_qsl = cgi.parse_qsl
-
 osprofiler_web = importutils.try_import("osprofiler.web")
 
 
