@@ -157,11 +157,34 @@ class Modules(base.ManagerWithFind):
         common.check_for_exceptions(resp, body, url)
 
     def instances(self, module, limit=None, marker=None,
-                  include_clustered=False):
+                  include_clustered=False, count_only=False):
         """Get a list of all instances this module has been applied to."""
         url = "/modules/%s/instances" % base.getid(module)
         query_strings = {}
         if include_clustered:
             query_strings['include_clustered'] = include_clustered
+        if count_only:
+            query_strings['count_only'] = count_only
         return self._paginated(url, "instances", limit, marker,
                                query_strings=query_strings)
+
+    def reapply(self, module, md5=None, include_clustered=None,
+                batch_size=None, delay=None, force=None):
+        """Reapplies the specified module."""
+        url = "/modules/%s/instances" % base.getid(module)
+        body = {
+            "reapply": {
+            }
+        }
+        if md5:
+            body["reapply"]["md5"] = md5
+        if include_clustered is not None:
+            body["reapply"]["include_clustered"] = int(include_clustered)
+        if batch_size is not None:
+            body["reapply"]["batch_size"] = batch_size
+        if delay is not None:
+            body["reapply"]["batch_delay"] = delay
+        if force is not None:
+            body["reapply"]["force"] = int(force)
+        resp, body = self.api.client.put(url, body=body)
+        common.check_for_exceptions(resp, body, url)
